from django.apps import AppConfig


class DjUtilsConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'dj_utils'
    def ready(self):
        from . import handlers
        from . import tasks_config
